@@ -460,8 +460,6 @@ sub load_entry {
     my $current_buffer; # to add lines
     LINE:
     while (my $line = <$file_handle>) {
-        defined $line
-            or last LINE;
         $line =~ s{\Q$eol\E \z}{}xms;
         my $line_number = ++${$line_number_ref};
         if ( $line =~ m{\A \s* \z}xms ) {
@@ -562,8 +560,6 @@ sub _hash_key_ok {
 
 __END__
 
-# Below is the stub of documentation for your module. You better edit it!
-
 =head1 NAME
 
 DBD::PO::Locale::PO - Perl module for manipulating .po entries from GNU gettext
